Get information from a raster
grass_raster_info.RdThis function gets information from a raster layer in GRASS GIS and returns
it as a list. It is a wrapper for module r.info() in GRASS GIS.
grass_raster_info.RdThis function gets information from a raster layer in GRASS GIS and returns
it as a list. It is a wrapper for module r.info() in GRASS GIS.